%{!?upstream_version: %global upstream_version %{version}%{?milestone}}
%global pypi_name networking-bigswitch
%global module_name networking_bigswitch
%global rpm_prefix openstack-neutron-bigswitch
%global docpath doc/build/html
%global lib_dir %{buildroot}%{python2_sitelib}/%{module_name}/plugins/bigswitch

Name:           python-%{pypi_name}
Epoch:          2
Version:        10.0.8
Release:        1%{?dist}
Summary:        Big Switch Networks neutron plugin for OpenStack Networking
License:        ASL 2.0
URL:            https://pypi.python.org/pypi/%{pypi_name}
Source0:        https://pypi.io/packages/source/n/%{pypi_name}/%{pypi_name}-%{upstream_version}.tar.gz
Source1:        neutron-bsn-agent.service
Source2:        neutron-bsn-lldp.service
Provides: python2-networking-bigswitch = %{epoch}:%{version}-%{release}
BuildArch:      noarch

#
#patches_ignore=DROP-IN-RPM
#patches_base=10.0.8
Patch0001: 0001-Resolve-setup.cfg-munging-by-setuptools.patch
Patch0002: 0002-Checks-and-creates-bsn_tables-if-not-already-created.patch

BuildRequires:  python-devel
BuildRequires:  python-pbr
BuildRequires:  python-setuptools
BuildRequires:  python-sphinx
BuildRequires:  systemd-units

Requires:       openstack-neutron-common >= 1:7.0.0
Requires:       python-pbr >= 0.10.8
Requires:       python-oslo-log >= 1.0.0
Requires:       python-oslo-config >= 2:1.9.3
Requires:       python-oslo-utils >= 1.4.0
Requires:       python-oslo-messaging >= 1.8.0
Requires:       python-oslo-serialization >= 1.4.0

Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd

%description
This package contains Big Switch Networks
neutron plugins and agents

%package -n %{rpm_prefix}-agent
Summary:        Neutron Big Switch Networks agent
Requires:       python-%{pypi_name} = %{epoch}:%{version}-%{release}

%description -n %{rpm_prefix}-agent
This package contains the Big Switch Networks
neutron agent for security groups.

%package -n %{rpm_prefix}-lldp
Summary:        Neutron Big Switch Networks LLDP service
Requires:       python-%{pypi_name} = %{epoch}:%{version}-%{release}

%description -n %{rpm_prefix}-lldp
This package contains the Big Switch Networks neutron LLDP agent.

%package doc
Summary:        Neutron Big Switch Networks plugin documentation

%description doc
This package contains the documentation for
Big Switch Networks neutron plugins.

%prep
%setup -q -n %{pypi_name}-%{upstream_version}

%patch0001 -p1
%patch0002 -p1

%build
export PBR_VERSION=%{version}
export SKIP_PIP_INSTALL=1
%{__python2} setup.py build
%{__python2} setup.py build_sphinx
rm %{docpath}/.buildinfo

%install
%{__python2} setup.py install --skip-build --root %{buildroot}
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/neutron-bsn-agent.service
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/neutron-bsn-lldp.service
mkdir -p %{buildroot}/%{_sysconfdir}/neutron/conf.d/neutron-bsn-agent
mkdir -p %{lib_dir}/tests
for lib in %{lib_dir}/version.py %{lib_dir}/tests/test_server.py; do
    sed '1{\@^#!/usr/bin/env python@d}' $lib > $lib.new &&
    touch -r $lib $lib.new &&
    mv $lib.new $lib
done

# moving the file seems to break setup.py install rhbz#1455141
install -p -D -m 664 networking_bigswitch/plugins/bigswitch/db/migration/alembic_migrations/versions/f774eae87144_rename_tenant_to_project.py %{buildroot}/usr/lib/python2.7/site-packages/networking_bigswitch/plugins/bigswitch/db/migration/alembic_migrations/versions/

%files
%license LICENSE
%{python2_sitelib}/%{module_name}
%{python2_sitelib}/*.egg-info

%config %{_sysconfdir}/neutron/policy.d/bsn_plugin_policy.json

%files -n %{rpm_prefix}-agent
%license LICENSE
%{_unitdir}/neutron-bsn-agent.service
%{_bindir}/neutron-bsn-agent
%dir %{_sysconfdir}/neutron/conf.d/neutron-bsn-agent

%files -n %{rpm_prefix}-lldp
%license LICENSE
%{_unitdir}/neutron-bsn-lldp.service
%{_bindir}/bsnlldp

%files doc
%license LICENSE
%doc README.rst
%doc %{docpath}

%post
%systemd_post neutron-bsn-agent.service
%systemd_post neutron-bsn-lldp.service

%preun
%systemd_preun neutron-bsn-agent.service
%systemd_preun neutron-bsn-lldp.service

%postun
%systemd_postun_with_restart neutron-bsn-agent.service
%systemd_postun_with_restart neutron-bsn-lldp.service

%changelog
* Fri Nov 10 2017 Jason Joyce <jjoyce@redhat.com> 2:10.0.8-1
- Update to 10.0.8

* Wed Sep 27 2017 Jason Joyce <jjoyce@redhat.com> 2:10.0.7-3
- IN-250: fetch git tags outside container
- IN-250: remove pip/apt-get install from build jobs
- Revert "use neutron_lib for extra_dhcp_opts"

* Mon Aug 21 2017 Jason Joyce <jjoyce@redhat.com> 2:10.0.7-2
- Add a few more sets of ML2 Unit Tests
- use neutron_lib for extra_dhcp_opts
- Fix const import to use neutron_lib
- don't guard transaction in update_router
- test release with git tagging
- Revert "Re-sync a few file files from the tarball"

* Tue Aug 15 2017 Steve Linabery <slinaber@redhat.com> 2:10.0.7-1
- Update to 10.0.7

* Wed Jun 28 2017 Mike Burns <mburns@redhat.com> 2:10.0.6-1
- Update to 10.0.6

* Tue May 30 2017 Mike Burns <mburns@redhat.com> 2:10.0.4-7
- ensure the file from rhbz#1455141 is actually available

* Fri May 26 2017 Steve Linabery <slinaber@redhat.com> 2:10.0.4-6
- OSP-21: fix dangling move of files (rhbz#1455141)

* Mon May 22 2017 Steve Linabery <slinaber@redhat.com> 2:10.0.4-5
- Checks and creates bsn_tables if not already created

* Thu Apr 27 2017 Mike Burns <mburns@redhat.com> 2:10.0.4-4
- readd python2 provides

* Fri Apr 21 2017 Mike Burns <mburns@redhat.com> 2:10.0.4-2
- Update epoch to make rpm updates work rhbz#1444142

* Mon Apr 17 2017 Steve Linabery <slinaber@redhat.com> 1:10.0.4-2
- BVS-5916: handle special characters in object names
- OSP-43: dont support pci passthrough vnic type

* Wed Apr 12 2017 Steve Linabery <slinaber@redhat.com> 1:10.0.4-1
- Update to 10.0.4

* Mon Apr 03 2017 Jon Schlueter <jschluet@redhat.com> 1:10.0.3-2
- BVS-5916: allow spaces in security group names
- BVS-7861: ignore description when syncing with controller

* Wed Mar 29 2017 Jon Schlueter <jschluet@redhat.com> 1:10.0.3-1
- Update to 10.0.3

* Wed Mar 22 2017 Mike Burns <mburns@redhat.com> 1:10.0.1-2
- Merge "OSP-47: ensure tenant_id is changed to project_id newton upwards" into stable/ocata
- OSP-47: ensure tenant_id is changed to project_id newton upwards
- ensure all keystone conf is read from config file

